/**
 * Signal indicating if the Swipe Behavior component is currently mounted.
 */
export declare const _isMounted: import('@telegram-apps/signals').Signal<boolean>, isMounted: import('@telegram-apps/signals').Computed<boolean>;
/**
 * Signal indicating if the Swipe Behavior is supported.
 */
export declare const isSupported: import('@telegram-apps/signals').Computed<boolean>;
/**
 * Signal indicating if vertical swipes are enabled.
 */
export declare const _isVerticalEnabled: import('@telegram-apps/signals').Signal<boolean>, isVerticalEnabled: import('@telegram-apps/signals').Computed<boolean>;
/**
 * Disables vertical swipes.
 * @since Mini Apps v7.7
 * @throws {FunctionNotAvailableError} The environment is unknown
 * @throws {FunctionNotAvailableError} The SDK is not initialized
 * @throws {FunctionNotAvailableError} The function is not supported
 * @throws {FunctionNotAvailableError} The parent component is not mounted
 * @example
 * if (disableVertical.isAvailable()) {
 *   disableVertical();
 * }
 */
export declare const disableVertical: import('../../wrappers/wrapSafe.js').SafeWrapped<() => void, true, never>;
/**
 * Enables vertical swipes.
 * @since Mini Apps v7.7
 * @throws {FunctionNotAvailableError} The environment is unknown
 * @throws {FunctionNotAvailableError} The SDK is not initialized
 * @throws {FunctionNotAvailableError} The function is not supported
 * @throws {FunctionNotAvailableError} The parent component is not mounted
 * @example
 * if (enableVertical.isAvailable()) {
 *   enableVertical();
 * }
 */
export declare const enableVertical: import('../../wrappers/wrapSafe.js').SafeWrapped<() => void, true, never>;
/**
 * Mounts the Swipe Behavior component restoring its state.
 * @since Mini Apps v7.7
 * @throws {FunctionNotAvailableError} The environment is unknown
 * @throws {FunctionNotAvailableError} The SDK is not initialized
 * @throws {FunctionNotAvailableError} The function is not supported
 * @example
 * if (mount.isAvailable()) {
 *   mount();
 * }
 */
export declare const mount: import('../../wrappers/wrapSafe.js').SafeWrapped<() => void, true, never>;
/**
 * Unmounts the Swipe Behavior component.
 */
export declare function unmount(): void;
