import { WriteAccessRequestedStatus } from '@telegram-apps/bridge';
import { AbortablePromise } from 'better-promises';
import { RequestOptionsNoCapture } from '../../../types.js';
/**
 * Requests write message access to the current user.
 * @param options - additional options.
 * @since Mini Apps v6.9
 * @throws {ConcurrentCallError} Write access request is currently in progress
 * @throws {FunctionNotAvailableError} The environment is unknown
 * @throws {FunctionNotAvailableError} The SDK is not initialized
 * @throws {FunctionNotAvailableError} The function is not supported
 * @example
 * if (requestWriteAccess.isAvailable()) {
 *   const status = await requestWriteAccess();
 * }
 */
export declare const requestWriteAccess: import('../../wrappers/wrapSafe.js').SafeWrapped<(options?: RequestOptionsNoCapture) => AbortablePromise<WriteAccessRequestedStatus>, true, never>;
export declare const requestWriteAccessPromise: import('@telegram-apps/signals').Computed<AbortablePromise<string> | undefined>, isRequestingWriteAccess: import('@telegram-apps/signals').Computed<boolean>;
export declare const requestWriteAccessError: import('@telegram-apps/signals').Computed<Error | undefined>;
